@@ -33,12 +33,8 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#ifdef USE_GTKFILECHOOSER
 #include <gtk/gtkfilechooser.h>
 #include <gtk/gtkfilechooserdialog.h>
-#else
-#include <gtk/gtkfilesel.h>
-#endif
 #include <bonobo.h>
 
 #include "htmlengine.h"
@@ -97,7 +93,6 @@ insert_image_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cna
 	GtkWidget *filesel;
 	HTMLObject *img;
 
-#ifdef USE_GTKFILECHOOSER
 	filesel = gtk_file_chooser_dialog_new (_("Insert image"),
 					       NULL,
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -105,23 +100,12 @@ insert_image_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cna
 					       GTK_STOCK_OPEN, GTK_RESPONSE_OK,
 					       NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (filesel), GTK_RESPONSE_OK);
-#else
-	filesel = gtk_file_selection_new (_("Insert image"));
-#endif
 	if (filesel) {
 		if (gtk_dialog_run (GTK_DIALOG (filesel)) == GTK_RESPONSE_OK) {
-#ifdef USE_GTKFILECHOOSER
 			char *filename;
-#else
-			const char *filename;
-#endif
 			char *url = NULL;
 
-#ifdef USE_GTKFILECHOOSER
 			filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (filesel));
-#else
-			filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (filesel));
-#endif
 			url = gtk_html_filename_to_uri (filename);
 			g_free(filename);
 			img = html_image_new (html_engine_get_image_factory (cd->html->engine), url,
@@ -224,11 +208,7 @@ file_dialog_ok (GtkWidget *w, GtkHTMLControlData *cd)
 	gsize len = 0;
 	const char *charset;
 
-#ifdef USE_GTKFILECHOOSER
 	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (cd->file_dialog));
-#else	
-	filename = gtk_file_selection_get_filename (GTK_FILE_SELECTION (cd->file_dialog));
-#endif
 	io = g_io_channel_new_file (filename, "r", &error);
 
 	if (error || !io)
@@ -316,7 +296,6 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 		return;
 	}
 
-#ifdef USE_GTKFILECHOOSER
 	cd->file_dialog = gtk_file_chooser_dialog_new (html ? _("Insert HTML File") : _("Insert Text File"),
 						       NULL,
 						       GTK_FILE_CHOOSER_ACTION_OPEN,
@@ -325,10 +304,6 @@ insert_file_dialog (GtkHTMLControlData *cd, gboolean html)
 						       NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (cd->file_dialog), GTK_RESPONSE_OK);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (cd->file_dialog), g_get_home_dir ());
-#else
-	cd->file_dialog = gtk_file_selection_new (html ? _("Insert HTML File") : _("Insert Text File"));
-	gtk_file_selection_set_filename (GTK_FILE_SELECTION (cd->file_dialog), "~/");
-#endif
 
 	if (cd->file_dialog) {
 		if (gtk_dialog_run (GTK_DIALOG (cd->file_dialog)) == GTK_RESPONSE_OK) {
@@ -695,7 +670,6 @@ smiley_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname)
 	g_assert (icon_info != NULL);
 	filename = gtk_icon_info_get_filename (icon_info);
 	g_assert (filename != NULL);
-	gtk_icon_info_free (icon_info);
 	g_free (icon_name);
 
 	switch (smiley) {
@@ -739,6 +713,7 @@ smiley_cb (BonoboUIComponent *uic, GtkHTMLControlData *cd, const char *cname)
 	html = g_strdup_printf ("<IMG ALT=\"%s\" SRC=\"%s\">",
 		emoticon, filename);
 	gtk_html_insert_html (cd->html, html);
+	gtk_icon_info_free (icon_info);
 	g_free (html);
 }
 
